@@ -237,7 +237,7 @@ class PlotPanel(wx.Panel):
     def tab_complete_file(self):
         filedir = self._text_ctrl.GetValue()
         tokens = filedir.split()
-        if(len(tokens) == 2):
+        if(len(tokens) == 2 and tokens[0]!='save'):
             text = tokens[1]
         elif(len(tokens) == 3 and tokens[0]=='save'):
             text = tokens[2]
